@@ -16,7 +16,7 @@ APcontours <- function(inRaster, interval, max.contour.segments = NULL){
   }
 
   # Get minimum and maximum raster values
-  rasInfo <- tryCatch(rgdal::GDALinfo(inRaster@file@name), warning = function(x) FALSE, error = function(e) FALSE)
+  rasInfo <- suppressWarnings(tryCatch(rgdal::GDALinfo(inRaster@file@name), error = function(e) FALSE))
   rasterRange <- if(class(rasInfo) == "GDALobj"){
     unlist(attributes(rasInfo)$df[,c("Bmin", "Bmax")])
   }else{
