@@ -4,20 +4,19 @@
 #' was adapted from the solution developed by John Baumgartner and Francisco Rodriguez-Sanchez.
 #'
 #' This function needs OSGeo4W to be installed. The OSGeo4W installation path,
-#' set to 'C:\\OSGeo4W64' by default, will then be used to find the \emph{OSGeo4W.bat} and \emph{gdal_polygonize.py}
-#' files. Python must be installed in order to run \emph{gdal_polygonize.py}.
+#' set to 'C:/OSGeo4W64' by default, will then be used to find the \emph{gdal_polygonize.bat}
+#' file.
 #'
 #' @param inRaster a RasterLayer or a path to a raster file
-#' @param OSGeoPath character. Path to the OSGeo4W installation directory
 #' @param readToMemory logical. Read output polygons into memory as a SpatialPolygonsDataFrame
 #' @param outFile character. Optional path for saving output as an Esri Shapefile.
+#' @param OSGeoPath character. Path to the OSGeo4W installation directory
 #' @param connectivity numeric. Can be either set to 4 (rook's case) or 8 (queen's case)
 #'
-#'
 #' @return SpatialPolygonsDataFrame
 #'
 #' @seealso \itemize{
-#' \item GDAL: \url{http://www.gdal.org/}
+#' \item GDAL: \url{https://gdal.org/}
 #' \item OSGeo4W download page: \url{https://trac.osgeo.org/osgeo4w/}
 #' \item John Baumgartner's blog post on \emph{gdal_polygonize}: \url{https://johnbaumgartner.wordpress.com/2012/07/26/getting-rasters-into-shape-from-r/}
 #' }
@@ -26,20 +25,18 @@
 #'
 #' @export
 
-APpolygonize <- function(inRaster, readToMemory = TRUE, outFile = NULL, OSGeoPath = "C:\\OSGeo4W64", connectivity = 4){
+APpolygonize <- function(inRaster, readToMemory = TRUE, outFile = NULL, OSGeoPath = "C:/OSGeo4W64", connectivity = 4){
 
   if(!connectivity %in% c(4,8)) stop("Connectivity can only be 4 or 8")
 
   # Check if OSGeo files exist
   if(!file.exists(OSGeoPath)) stop("Could not find folder '", OSGeoPath, "'")
-  batpath <- file.path(OSGeoPath,"OSGeo4W.bat")
-  if(!file.exists(batpath)) stop("Could not find required file '", batpath, "'")
-  polpath <- file.path(OSGeoPath, "bin\\gdal_polygonize.py")
-  if(!file.exists(polpath)) stop("Could not find required file '", polpath, "'")
-  pypath <- file.path(OSGeoPath, "apps\\Python27\\lib\\site-packages\\osgeo\\__init__.py")
-  if(!file.exists(pypath)) stop("Could not find required file '", pypath, "'. Python may not have been installed with OSGeo")
 
-  # Create temporary outfile if needed
+  # Get path for 'gdal_polygonize.bat'
+  batPath <- file.path(OSGeoPath, "bin", "gdal_polygonize.bat")
+  if(!file.exists(batPath)) stop("Could not find required file '", batPath, "'")
+
+  # Create temporary output file if needed
   if(is.null(outFile)){
 
     outFile <- tempfile(fileext = ".shp")
@@ -56,15 +53,15 @@ APpolygonize <- function(inRaster, readToMemory = TRUE, outFile = NULL, OSGeoPat
     # Check if 'inRaster' is already on the disk AND has an accepted file format
     deniedFormat <- c("grd")
     if(raster::fromDisk(inRaster) && !tools::file_ext(inRaster@file@name) %in% deniedFormat){
-      rastpath <- normalizePath(inRaster@file@name)
+      rastPath <- normalizePath(inRaster@file@name)
     }else{
-      rastpath <- tempfile(fileext='.asc')
-      raster::writeRaster(inRaster, rastpath)
-      on.exit(unlink(rastpath), add = TRUE)
+      rastPath <- tempfile(fileext='.asc')
+      raster::writeRaster(inRaster, rastPath)
+      on.exit(unlink(rastPath), add = TRUE)
     }
   }else{
     if(is.character(inRaster)){
-      rastpath <- normalizePath(inRaster)
+      rastPath <- normalizePath(inRaster)
       inRaster <- raster::raster(inRaster)
     }else{
       stop("'inRaster' must be a file path (character string), or a Raster object.")
@@ -75,11 +72,14 @@ APpolygonize <- function(inRaster, readToMemory = TRUE, outFile = NULL, OSGeoPat
   if(connectivity == 8) connectivity <- "-8 " else connectivity <- ""
 
   # Make vector of arguments
-  args <- sprintf('"%1$s" %2$s "%3$s" -f "%4$s" "%5$s" -q',
-                  sub('\\.py$', '', polpath), connectivity, rastpath, "ESRI Shapefile", outFile)
+  args <- sprintf('%1$s "%2$s" -f "%3$s" "%4$s" -q',
+                  connectivity, rastPath, "ESRI Shapefile", outFile)
 
-  # Run OSGeo function (silence poutput by setting 'stdout' to TRUE)
-  outputText <- system2(batpath, args = args, stdout = TRUE)
+  # Run OSGeo function (silence output by setting 'stdout' to TRUE)
+  outputText <- withr::with_envvar(c(OSGEO4W_ROOT = OSGeoPath), system2(batPath, args = args, stdout = TRUE))
+
+  # Check if successful
+  if(!file.exists(outFile)) stop("Failed to create output file")
 
   # Read output shapefile
   if(readToMemory){
